.. capnpy documentation master file, created by
   sphinx-quickstart on Thu Nov 10 16:12:36 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
capnpy documentation
==================================

``capnpy`` is an implementation of Cap'n Proto for Python. Its primary goal is
to provide a library which is fast, both on CPython and PyPy, and which offers
a pythonic API and feeling whenever possible.

.. toctree::
   :maxdepth: 3

   usage
   changelog
   benchmarks
